🚣 ⛵ odyssey ⛵ 🚣
=====================

odyssey is a cross-platform cross-architecture cross-scm workspace management tool. It is designed from the ground up to support multi-repository workflows, and is easily extended to work with any scm or package management tool out there. Although odyssey is written in python, it will work for multi-repository projects in any programming language, even ones that use multiple languages.

*Even if it will take ten years, it will have been worth it.*

.. image:: https://img.shields.io/badge/platform-windows%20%7C%20osx%20%7C%20ubuntu%20%7C%20alpine-lightgrey
    :alt: Supported Platforms

.. image:: https://img.shields.io/badge/architecture-x86%20%7C%20amd64%20%7C%20arm64-lightgrey
    :alt: Supported CPU Architectures

.. image:: https://img.shields.io/github/v/release/python-odyssey/odyssey
    :target: https://github.com/python-odyssey/odyssey/releases
    :alt: GitHub Release

.. image:: https://img.shields.io/pypi/v/odyssey
    :target: https://pypi.org/project/odyssey/
    :alt: PyPI

.. image:: https://img.shields.io/travis/com/python-odyssey/odyssey/master?label=travis
    :target: https://travis-ci.com/python-odyssey/odyssey
    :alt: Travis

.. image:: https://img.shields.io/appveyor/build/GodwinneLorayne/odyssey/master?label=appveyor
    :target: https://ci.appveyor.com/project/GodwinneLorayne/odyssey
    :alt: AppVeyor

.. image:: https://img.shields.io/circleci/build/github/python-odyssey/odyssey/master?label=circleci
    :target: https://circleci.com/gh/python-odyssey/odyssey/tree/master
    :alt: CircleCI

.. image:: https://img.shields.io/github/workflow/status/python-odyssey/odyssey/Python%20package/master?label=github
    :target: https://github.com/python-odyssey/odyssey/actions?query=workflow%3A%22Python+package%22
    :alt: GitHub Workflow

.. image:: https://img.shields.io/codeship/9d611200-8038-0138-868a-7e7dbe13f4dd/master?label=codeship
    :target: https://app.codeship.com/projects/9d611200-8038-0138-868a-7e7dbe13f4dd
    :alt: Codeship

.. image:: https://readthedocs.org/projects/python-odyssey/badge/?version=latest
    :target: https://python-odyssey.readthedocs.io/en/latest/index.html
    :alt: Documentation Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

.. image:: https://coveralls.io/repos/github/python-odyssey/odyssey/badge.svg?branch=master
    :target: https://coveralls.io/github/python-odyssey/odyssey?branch=master

.. image:: https://img.shields.io/github/languages/code-size/python-odyssey/odyssey
    :alt: GitHub code size in bytes

.. image:: https://img.shields.io/github/issues-raw/python-odyssey/odyssey
    :alt: GitHub issues

.. image:: https://img.shields.io/github/license/python-odyssey/odyssey
    :alt: GitHub

.. image:: https://img.shields.io/github/stars/python-odyssey/odyssey
    :alt: GitHub stars

.. image:: https://img.shields.io/discord/714011709794418698
    :target: https://discord.com/channels/714011709794418698
